@@ -207,7 +207,7 @@ def gcp_cost(args):
     # save current default GCP project
     original_project = None
     try:
-        original_project = elastic_blast.elb_config.get_gcp_project()
+        original_project = elastic_blast.util.get_gcp_project()
     except (SafeExecError, RuntimeError) as err:
         print('Error: Could not get current GCP project')
         print(err, file=sys.stderr)
